# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKOptimizersv4Python



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkMultiGradientOptimizerv4Python
else:
    import _itkMultiGradientOptimizerv4Python

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkObjectToObjectOptimizerBasePython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.itkOptimizerParameterScalesEstimatorPython
import itk.itkObjectToObjectMetricBasePython
import itk.itkSingleValuedCostFunctionv4Python
import itk.itkCostFunctionPython
import itk.itkGradientDescentOptimizerv4Python
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkGradientDescentOptimizerBasev4Python

def itkMultiGradientOptimizerv4TemplateD_New():
    return itkMultiGradientOptimizerv4TemplateD.New()

class itkMultiGradientOptimizerv4TemplateD(itk.itkGradientDescentOptimizerv4Python.itkGradientDescentOptimizerv4TemplateD):
    r"""Proxy of C++ itkMultiGradientOptimizerv4TemplateD class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMultiGradientOptimizerv4TemplateD_Pointer"""
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateD___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMultiGradientOptimizerv4TemplateD_Pointer"""
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateD_Clone(self)

    def StartOptimization(self, doOnlyInitialization=False):
        r"""
        StartOptimization(self, doOnlyInitialization=False)

        Parameters
        ----------
        doOnlyInitialization: bool

        """
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateD_StartOptimization(self, doOnlyInitialization)

    def GetOptimizersList(self):
        r"""GetOptimizersList(self) -> std::vector< itkGradientDescentOptimizerv4TemplateD_Pointer,std::allocator< itkGradientDescentOptimizerv4TemplateD_Pointer > > &"""
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateD_GetOptimizersList(self)

    def SetOptimizersList(self, p):
        r"""
        SetOptimizersList(self, p)

        Parameters
        ----------
        p: std::vector< itkGradientDescentOptimizerv4TemplateD_Pointer,std::allocator< itkGradientDescentOptimizerv4TemplateD_Pointer > > &

        """
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateD_SetOptimizersList(self, p)

    def GetMetricValuesList(self):
        r"""GetMetricValuesList(self) -> vectorD"""
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateD_GetMetricValuesList(self)
    __swig_destroy__ = _itkMultiGradientOptimizerv4Python.delete_itkMultiGradientOptimizerv4TemplateD

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMultiGradientOptimizerv4TemplateD

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateD_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMultiGradientOptimizerv4TemplateD

        Create a new object of the class itkMultiGradientOptimizerv4TemplateD and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMultiGradientOptimizerv4TemplateD.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMultiGradientOptimizerv4TemplateD.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMultiGradientOptimizerv4TemplateD.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMultiGradientOptimizerv4TemplateD in _itkMultiGradientOptimizerv4Python:
_itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateD_swigregister(itkMultiGradientOptimizerv4TemplateD)

def itkMultiGradientOptimizerv4TemplateF_New():
    return itkMultiGradientOptimizerv4TemplateF.New()

class itkMultiGradientOptimizerv4TemplateF(itk.itkGradientDescentOptimizerv4Python.itkGradientDescentOptimizerv4TemplateF):
    r"""Proxy of C++ itkMultiGradientOptimizerv4TemplateF class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkMultiGradientOptimizerv4TemplateF_Pointer"""
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateF___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkMultiGradientOptimizerv4TemplateF_Pointer"""
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateF_Clone(self)

    def StartOptimization(self, doOnlyInitialization=False):
        r"""
        StartOptimization(self, doOnlyInitialization=False)

        Parameters
        ----------
        doOnlyInitialization: bool

        """
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateF_StartOptimization(self, doOnlyInitialization)

    def GetOptimizersList(self):
        r"""GetOptimizersList(self) -> std::vector< itkGradientDescentOptimizerv4TemplateF_Pointer,std::allocator< itkGradientDescentOptimizerv4TemplateF_Pointer > > &"""
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateF_GetOptimizersList(self)

    def SetOptimizersList(self, p):
        r"""
        SetOptimizersList(self, p)

        Parameters
        ----------
        p: std::vector< itkGradientDescentOptimizerv4TemplateF_Pointer,std::allocator< itkGradientDescentOptimizerv4TemplateF_Pointer > > &

        """
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateF_SetOptimizersList(self, p)

    def GetMetricValuesList(self):
        r"""GetMetricValuesList(self) -> vectorF"""
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateF_GetMetricValuesList(self)
    __swig_destroy__ = _itkMultiGradientOptimizerv4Python.delete_itkMultiGradientOptimizerv4TemplateF

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkMultiGradientOptimizerv4TemplateF

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateF_cast(obj)

    def New(*args, **kargs):
        """New() -> itkMultiGradientOptimizerv4TemplateF

        Create a new object of the class itkMultiGradientOptimizerv4TemplateF and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkMultiGradientOptimizerv4TemplateF.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkMultiGradientOptimizerv4TemplateF.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkMultiGradientOptimizerv4TemplateF.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkMultiGradientOptimizerv4TemplateF in _itkMultiGradientOptimizerv4Python:
_itkMultiGradientOptimizerv4Python.itkMultiGradientOptimizerv4TemplateF_swigregister(itkMultiGradientOptimizerv4TemplateF)

